@@ -564,7 +564,7 @@ create_entry_date (GdauiEntryCommonTime *mgtim)
 	GdaDataHandler *dh;
 
 	/* top widget */
-	hb = gtk_hbox_new (FALSE, 3);
+	hb = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
 
 	/* text entry */
 	dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgtim));
@@ -833,10 +833,8 @@ date_calendar_choose_cb (GtkWidget *button, GdauiEntryCommonTime *mgtim)
 	GValue *value;
         guint year=0, month=0, day=0;
 	gboolean unset = TRUE;
-	GdaDataHandler *dh;
 
         /* setting the calendar to the latest displayed date */
-	dh = gdaui_data_entry_get_handler (GDAUI_DATA_ENTRY (mgtim));
 	value = gdaui_data_entry_get_value (GDAUI_DATA_ENTRY (mgtim));
 	
         if (value && !gda_value_is_null (value)) {
@@ -1077,7 +1075,7 @@ create_entry_ts (GdauiEntryCommonTime *mgtim)
 {
 	GtkWidget *hb, *wid;
 
-	hb = gtk_hbox_new (FALSE, 0);
+	hb = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	
 	/* date part */
 	wid = create_entry_date (mgtim);
