@@ -1,6 +1,6 @@
-/* gdaui-entry.c
- *
- * Copyright (C) 2009 Vivien Malerba <malerba@gnome-db.org>
+/*
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -103,6 +103,7 @@ gdaui_entry_get_type (void)
 			sizeof (GdauiEntry),
 			0,		/* n_preallocs */
 			(GInstanceInitFunc) gdaui_entry_init,
+			0
 		};
 		
 		type = g_type_register_static (GTK_TYPE_ENTRY, "GdauiEntry", &type_info, 0);
@@ -328,12 +329,12 @@ adjust_display (GdauiEntry *entry, gchar *existing_text)
 
 /**
  * gdaui_entry_new:
- * @prefix: a prefix (not modifiable) string, or %NULL
- * @suffix: a suffix (not modifiable) string, or %NULL
+ * @prefix: (allow-none): a prefix (not modifiable) string, or %NULL
+ * @suffix: (allow-none): a suffix (not modifiable) string, or %NULL
  *
  * Creates a new #GdauiEntry widget.
  *
- * Returns: the newly created #GdauiEntry widget.
+ * Returns: (transfer full): the newly created #GdauiEntry widget.
  */
 GtkWidget*
 gdaui_entry_new (const gchar *prefix, const gchar *suffix)
@@ -345,7 +346,7 @@ gdaui_entry_new (const gchar *prefix, const gchar *suffix)
 }
 
 /**
- * gdaui_entry_set_max_length
+ * gdaui_entry_set_max_length:
  * @entry: a #GdauiEntry.
  * @max: the maximum length of the entry, or 0 for no maximum.
  *
@@ -411,7 +412,7 @@ gdaui_entry_get_text (GdauiEntry *entry)
 }
 
 /**
- * gdaui_entry_set_text
+ * gdaui_entry_set_text:
  * @entry: a #GdauiEntry widget
  * @text: the text to set into @entry, or %NULL
  *
@@ -449,7 +450,7 @@ gdaui_entry_set_text (GdauiEntry *entry, const gchar *text)
 }
 
 /**
- * gdaui_entry_set_prefix
+ * gdaui_entry_set_prefix:
  * @entry: a #GdauiEntry widget
  * @prefix: a prefix string
  *
@@ -465,7 +466,7 @@ gdaui_entry_set_prefix (GdauiEntry *entry, const gchar *prefix)
 }
 
 /**
- * gdaui_entry_set_suffix
+ * gdaui_entry_set_suffix:
  * @entry: a #GdauiEntry widget
  * @suffix: a suffix string
  *
@@ -482,7 +483,7 @@ gdaui_entry_set_suffix (GdauiEntry *entry, const gchar *suffix)
 
 
 /**
- * gdaui_entry_set_width_chars
+ * gdaui_entry_set_width_chars:
  * @entry: a #GdauiEntry widget
  * @max_width: maximum width, or -1
  *
@@ -508,7 +509,7 @@ gdaui_entry_set_width_chars (GdauiEntry *entry, gint max_width)
  */
 
 static void
-changed_cb (GtkEditable *editable, gpointer data)
+changed_cb (GtkEditable *editable, G_GNUC_UNUSED gpointer data)
 {
         GdauiEntry *entry = (GdauiEntry*) editable;
         if (entry->priv->internal_changes > 0)
@@ -516,7 +517,7 @@ changed_cb (GtkEditable *editable, gpointer data)
 }
 
 static void
-delete_text_cb (GtkEditable *editable, gint start_pos, gint end_pos, gpointer data)
+delete_text_cb (GtkEditable *editable, gint start_pos, gint end_pos, G_GNUC_UNUSED gpointer data)
 {
 	const gchar *otext = NULL;
 	gint len;
@@ -579,7 +580,8 @@ delete_text_cb (GtkEditable *editable, gint start_pos, gint end_pos, gpointer da
 
 
 static void
-insert_text_cb (GtkEditable *editable, const gchar *text, gint text_length, gint *position, gpointer data)
+insert_text_cb (GtkEditable *editable, const gchar *text, gint text_length, gint *position,
+		G_GNUC_UNUSED gpointer data)
 {
 	const gchar *otext;
 	gint clen;
