@@ -1,21 +1,21 @@
-/* gdaui-data-cell-renderer-password.c
- *
- * Copyright (C) 2003 - 2010 Vivien Malerba <malerba@gdaui.org>
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <glib/gi18n-lib.h>
@@ -134,7 +134,7 @@ gdaui_data_cell_renderer_password_init (GdauiDataCellRendererPassword *datacell)
 {
 	datacell->priv = g_new0 (GdauiDataCellRendererPasswordPrivate, 1);
 	datacell->priv->dh = NULL;
-	datacell->priv->type = G_TYPE_INVALID;
+	datacell->priv->type = GDA_TYPE_NULL;
 	datacell->priv->type_forced = FALSE;
 	datacell->priv->value = NULL;
 	datacell->priv->options = NULL;
@@ -341,7 +341,7 @@ gdaui_data_cell_renderer_password_set_property (GObject *object,
  *
  * Creates a new #GdauiDataCellRendererPassword.
  *
- * Return value: the new cell renderer
+ * Returns: the new cell renderer
  **/
 GtkCellRenderer *
 gdaui_data_cell_renderer_password_new (GdaDataHandler *dh, GType type, const gchar *options)
@@ -386,19 +386,15 @@ gdaui_data_cell_renderer_password_render (GtkCellRenderer      *cell,
 	(text_class->render) (cell, cr, widget, background_area, cell_area, flags);
 
 	if (datacell->priv->to_be_deleted) {
-		GtkStyle *style;
+		GtkStyleContext *style_context = gtk_widget_get_style_context (widget);
 		guint xpad;
-
-		g_object_get ((GObject*) widget, "style", &style, NULL);
 		g_object_get ((GObject*) cell, "xpad", &xpad, NULL);
 
-		gtk_paint_hline (style,
-				 cr, GTK_STATE_SELECTED,
-				 widget,
-				 "hline",
+		gdouble y = cell_area->y + cell_area->height / 2.;
+		gtk_render_line (style_context,
+				 cr,
 				 cell_area->x + xpad, cell_area->x + cell_area->width - xpad,
-				 cell_area->y + cell_area->height / 2.);
-		g_object_unref (style);
+				 y, y);
 	}
 	if (datacell->priv->invalid)
 		gdaui_data_cell_renderer_draw_invalid_area (cr, cell_area);
