@@ -1,21 +1,21 @@
-/* gdaui-cloud.c
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * Copyright (C) 2009 - 2010 Vivien Malerba
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -114,7 +114,7 @@ gdaui_cloud_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "GdauiCloud", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "GdauiCloud", &info, 0);
 		g_type_add_interface_static (type, GDAUI_TYPE_DATA_SELECTOR, &selector_info);
 	}
 
@@ -125,11 +125,11 @@ static void
 cloud_map (GtkWidget *widget)
 {
         GTK_WIDGET_CLASS (parent_class)->map (widget);
-	GtkStyle *style;
-	GdkColor color;
-	style = gtk_widget_get_style (widget);
-	color = style->bg[GTK_STATE_NORMAL];
-	gtk_widget_modify_base (GDAUI_CLOUD (widget)->priv->tview, GTK_STATE_NORMAL, &color);
+	GtkStyleContext *style_context;
+	GdkRGBA color;
+	style_context = gtk_widget_get_style_context (widget);
+	gtk_style_context_get_background_color (style_context, GTK_STATE_FLAG_NORMAL, &color);
+	gtk_widget_override_background_color (GDAUI_CLOUD (widget)->priv->tview, GTK_STATE_FLAG_NORMAL, &color);
 }
 
 static void
@@ -347,6 +347,8 @@ gdaui_cloud_init (GdauiCloud *cloud)
 	cloud->priv->selected_tags = NULL;
 	cloud->priv->selection_mode = GTK_SELECTION_SINGLE;
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (cloud), GTK_ORIENTATION_VERTICAL);
+
 	/* text buffer */
         cloud->priv->tbuffer = gtk_text_buffer_new (NULL);
         gtk_text_buffer_create_tag (cloud->priv->tbuffer, "section",
@@ -360,7 +362,7 @@ gdaui_cloud_init (GdauiCloud *cloud)
                                         GTK_POLICY_AUTOMATIC);
         gtk_box_pack_start (GTK_BOX (cloud), sw, TRUE, TRUE, 0);
 
-        vbox = gtk_vbox_new (FALSE, 0);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	vp = gtk_viewport_new (NULL, NULL);
         gtk_viewport_set_shadow_type (GTK_VIEWPORT (vp), GTK_SHADOW_NONE);
 
@@ -1062,7 +1064,7 @@ gdaui_cloud_create_filter_widget (GdauiCloud *cloud)
 	GtkWidget *hbox, *label, *wid;
 	g_return_val_if_fail (GDAUI_IS_CLOUD (cloud), NULL);
 	
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 
 	label = gtk_label_new (_("Find:"));
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
