@@ -1,21 +1,21 @@
-/* gdaui-data-widget.c
+/*
+ * Copyright (C) 2009 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * Copyright (C) 2004 - 2010 Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
- * USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -51,7 +51,8 @@ gdaui_data_proxy_get_type (void)
 			NULL,
 			0,
 			0,
-			(GInstanceInitFunc) NULL
+			(GInstanceInitFunc) NULL,
+			0
 		};
 		
 		type = g_type_register_static (G_TYPE_INTERFACE, "GdauiDataProxy", &info, 0);
@@ -62,11 +63,21 @@ gdaui_data_proxy_get_type (void)
 
 
 static void
-gdaui_data_proxy_iface_init (gpointer g_class)
+gdaui_data_proxy_iface_init (G_GNUC_UNUSED gpointer g_class)
 {
 	static gboolean initialized = FALSE;
 
 	if (! initialized) {
+		/**
+		 * GdauiDataProxy::proxy-changed:
+		 * @gdauidataproxy: the #GdauiDataProxy
+		 * @arg1: the GdaDataProxy which would be returned by gdaui_data_proxy_get_proxy()
+		 *
+		 * The ::proxy-changed signal is emitted each time the #GdaDataProxy which would be
+		 * returned by gdaui_data_proxy_get_proxy() changes. This is generally the result
+		 * of changes in the structure of the proxied data model (different number and/or type
+		 * of columns for example).
+		 */
 		gdaui_data_proxy_signals[PROXY_CHANGED] = 
 			g_signal_new ("proxy-changed",
                                       GDAUI_TYPE_DATA_PROXY,
