@@ -198,7 +198,7 @@ gdaui_rt_editor_get_type (void)
 			0
 		};
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "GdauiRtEditor", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "GdauiRtEditor", &info, 0);
 	}
 
 	return type;
@@ -292,6 +292,8 @@ gdaui_rt_editor_init (GdauiRtEditor *rte)
 {
 	GtkWidget *sw, *textview, *toolbar;
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (rte), GTK_ORIENTATION_VERTICAL);
+
 	sw = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -841,7 +843,7 @@ bigger_font_item_activate_cb (G_GNUC_UNUSED GtkCheckMenuItem *checkmenuitem,
 	fd = pango_context_get_font_description (pcontext);
 	nfd = pango_font_description_copy_static (fd);
 	pango_font_description_set_size (nfd, pango_font_description_get_size (fd) * 1.2);
-	gtk_widget_modify_font (GTK_WIDGET (rte->priv->textview), nfd);
+	gtk_widget_override_font (GTK_WIDGET (rte->priv->textview), nfd);
 	pango_font_description_free (nfd);
 }
 
@@ -855,7 +857,7 @@ smaller_font_item_activate_cb (G_GNUC_UNUSED GtkCheckMenuItem *checkmenuitem,
 	fd = pango_context_get_font_description (pcontext);
 	nfd = pango_font_description_copy_static (fd);
 	pango_font_description_set_size (nfd, pango_font_description_get_size (fd) / 1.2);
-	gtk_widget_modify_font (GTK_WIDGET (rte->priv->textview), nfd);
+	gtk_widget_override_font (GTK_WIDGET (rte->priv->textview), nfd);
 	pango_font_description_free (nfd);
 }
 
@@ -863,7 +865,7 @@ static void
 reset_font_item_activate_cb (G_GNUC_UNUSED GtkCheckMenuItem *checkmenuitem,
 			     GdauiRtEditor *rte)
 {
-	gtk_widget_modify_font (GTK_WIDGET (rte->priv->textview), NULL);
+	gtk_widget_override_font (GTK_WIDGET (rte->priv->textview), NULL);
 }
 
 static void
