@@ -1,23 +1,21 @@
-/* GDA library
- * Copyright (C) 2009 - 2010 The GNOME Foundation.
+/*
+ * Copyright (C) 2009 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *      Vivien Malerba <malerba@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -379,7 +377,6 @@ gda_tree_node_get_property (GObject *object,
 	}	
 }
 
-#ifdef GDA_DEBUG_NO
 static void
 attributes_foreach_func (const gchar *att_name, const GValue *value, GString *string)
 {
@@ -387,8 +384,6 @@ attributes_foreach_func (const gchar *att_name, const GValue *value, GString *st
 	g_string_append_printf (string, " %s=%s", att_name, str);
 	g_free (str);
 }
-#endif
-
 
 static gchar *
 gda_tree_node_dump_header (GdaTreeNode *node)
@@ -397,23 +392,24 @@ gda_tree_node_dump_header (GdaTreeNode *node)
 
 	cvalue = gda_attributes_manager_get (gda_tree_node_attributes_manager, node,
 					     GDA_ATTRIBUTE_NAME);
-#ifdef GDA_DEBUG_NO
-	GString *string;
-	string = g_string_new ("");
-	if (cvalue)
-		g_string_append (string, g_value_get_string (cvalue));
-	else
-		g_string_append (string, "Unnamed node");
-	g_string_append_c (string, ':');
-	gda_attributes_manager_foreach (gda_tree_node_attributes_manager, node,
-					(GdaAttributesManagerFunc) attributes_foreach_func, string);
-	return g_string_free (string, FALSE);
-#else
-	if (cvalue)
-		return g_strdup (g_value_get_string (cvalue));
-	else
-		return g_strdup_printf ("Unnamed node");
-#endif
+	if (g_getenv ("GDA_TREE_DUMP_ALL_ATTRIBUTES")) {
+		GString *string;
+		string = g_string_new ("");
+		if (cvalue && (G_VALUE_TYPE (cvalue) == G_TYPE_STRING))
+			g_string_append (string, g_value_get_string (cvalue));
+		else
+			g_string_append (string, "Unnamed node");
+		g_string_append_c (string, ':');
+		gda_attributes_manager_foreach (gda_tree_node_attributes_manager, node,
+						(GdaAttributesManagerFunc) attributes_foreach_func, string);
+		return g_string_free (string, FALSE);
+	}
+	else {
+		if (cvalue)
+			return g_strdup (g_value_get_string (cvalue));
+		else
+			return g_strdup_printf ("Unnamed node");
+	}
 }
 
 
@@ -624,12 +620,11 @@ _gda_tree_node_add_children (GdaTreeNode *node, GdaTreeManager *mgr, const GSLis
 const GSList *
 _gda_tree_node_get_children_for_manager (GdaTreeNode *node, GdaTreeManager *mgr)
 {
-	GdaTreeNodesList *etn;
 	GSList *list;
 	g_return_val_if_fail (GDA_IS_TREE_NODE (node), NULL);
 	g_return_val_if_fail (GDA_IS_TREE_MANAGER (mgr), NULL);
 	
-	for (etn = NULL, list = node->priv->children; list; list = list->next) {
+	for (list = node->priv->children; list; list = list->next) {
 		if (GDA_TREE_NODES_LIST (list->data)->mgr == mgr)
 			return GDA_TREE_NODES_LIST (list->data)->nodes;
 	}
@@ -724,7 +719,7 @@ gda_tree_node_get_node_attribute (GdaTreeNode *node, const gchar *attribute)
  * gda_tree_node_set_node_attribute:
  * @node: a #GdaTreeNode
  * @attribute: attribute name
- * @value: a #GValue, or %NULL
+ * @value: (transfer none): a #GValue, or %NULL
  * @destroy: a function to be called when @attribute is not needed anymore, or %NULL
  *
  * Set the value associated to a named attribute. The @attribute string is used AS IT IS by this method (eg.
@@ -738,8 +733,8 @@ gda_tree_node_get_node_attribute (GdaTreeNode *node, const gchar *attribute)
  * For example one would use it as:
  *
  * <code>
- * gda_tree_node_set_node_attribute (node, g_strdup (my_attribute), g_free, my_value);
- * gda_tree_node_set_node_attribute (node, GDA_ATTRIBUTE_NAME, NULL, my_value);
+ * gda_tree_node_set_node_attribute (node, g_strdup (my_attribute), my_value, g_free);
+ * gda_tree_node_set_node_attribute (node, GDA_ATTRIBUTE_NAME, my_value, NULL);
  * </code>
  *
  * If there is already an attribute named @attribute set, then its value is replaced with the new value (@value is
@@ -752,13 +747,35 @@ gda_tree_node_set_node_attribute (GdaTreeNode *node, const gchar *attribute, con
 {
 	const GValue *cvalue;
 	g_return_if_fail (GDA_IS_TREE_NODE (node));
+	g_return_if_fail (attribute);
 
 	cvalue = gda_attributes_manager_get (gda_tree_node_attributes_manager, node, attribute);
 	if ((value && cvalue && !gda_value_differ (cvalue, value)) ||
 	    (!value && !cvalue))
 		return;
 
-	gda_attributes_manager_set_full (gda_tree_node_attributes_manager, node, attribute, value, destroy);
+	if (!strcmp (attribute, GDA_ATTRIBUTE_TREE_NODE_UNKNOWN_CHILDREN) &&
+	    (!value || (G_VALUE_TYPE (value) == G_TYPE_BOOLEAN))) {
+		gboolean ouc = FALSE;
+		gboolean nuc = FALSE;
+		if (cvalue && (G_VALUE_TYPE (cvalue) == G_TYPE_BOOLEAN) &&
+		    g_value_get_boolean (cvalue))
+			ouc = TRUE;
+
+		if (value && g_value_get_boolean (value))
+			nuc = TRUE;
+
+		if (ouc != nuc) {
+			gda_attributes_manager_set_full (gda_tree_node_attributes_manager, node,
+							 attribute, value, destroy);
+			g_signal_emit (node, gda_tree_node_signals[NODE_HAS_CHILD_TOGGLED], 0, node);
+			g_signal_emit (node, gda_tree_node_signals[NODE_CHANGED], 0, node);
+			return;
+		}
+	}
+
+	gda_attributes_manager_set_full (gda_tree_node_attributes_manager, node, attribute,
+					 value, destroy);
 	g_signal_emit (node, gda_tree_node_signals[NODE_CHANGED], 0, node);
 }
 
@@ -888,7 +905,7 @@ _gda_nodes_list_free (GdaTreeNodesList *nl)
 	if (nl->nodes) {
 		g_slist_foreach (nl->nodes, (GFunc) g_object_unref, NULL);
 		g_slist_free (nl->nodes);
-		g_object_unref (nl->mgr);
 	}
+	g_object_unref (nl->mgr);
 	g_free (nl);
 }
