@@ -4,6 +4,7 @@
  * Copyright (C) 2003 Danilo Schoeneberg <dj@starfire-programming.net>
  * Copyright (C) 2003 Laurent Sansonetti <lrz@gnome.org>
  * Copyright (C) 2005 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2011 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,21 +28,8 @@
 
 G_BEGIN_DECLS
 
-/* Boxed type for GError will not be done in GLib see bug #300610 */
-#define GDA_TYPE_ERROR (_gda_error_get_type())
-/**
- * GdaError: (skip)
- *
- */
-typedef GError GdaError;
-GType   _gda_error_get_type (void) G_GNUC_CONST;
-
 /* Pointer type for GSList (not a boxed type!) */
 #define GDA_TYPE_SLIST (_gda_slist_get_type())
-/**
- * GdaSList: (skip)
- *
- */
 typedef GSList GdaSList;
 GType   _gda_slist_get_type (void) G_GNUC_CONST;
 
