@@ -1,5 +1,5 @@
 
-/* Generated data (by glib-mkenums) */
+
 
 #include <sql-parser/gda-sql-parser.h>
 #include <sql-parser/gda-sql-statement.h>
@@ -188,6 +188,7 @@ gda_sql_operator_type_get_type (void)
       { GDA_SQL_OPERATOR_TYPE_BITAND, "GDA_SQL_OPERATOR_TYPE_BITAND", "bitand" },
       { GDA_SQL_OPERATOR_TYPE_BITOR, "GDA_SQL_OPERATOR_TYPE_BITOR", "bitor" },
       { GDA_SQL_OPERATOR_TYPE_BITNOT, "GDA_SQL_OPERATOR_TYPE_BITNOT", "bitnot" },
+      { GDA_SQL_OPERATOR_TYPE_ILIKE, "GDA_SQL_OPERATOR_TYPE_ILIKE", "ilike" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GdaSqlOperatorType", values);
@@ -213,12 +214,5 @@ gda_sql_select_join_type_get_type (void)
   return etype;
 }
 
-/* Generated data ends here */
 
-/* Content designed to maitain API/ABI */
 
-GType
-gda_sql_error_type_get_type (void)
-{
-  return gda_sql_error_get_type ();
-}
\ No newline at end of file
