@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2008 - 2009 Bas Driessen <bas.driessen@xobas.com>
- * Copyright (C) 2008 - 2009 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2008 - 2011 Vivien Malerba <malerba@gnome-db.org>
  * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -79,10 +79,7 @@ gda_sql_expr_free (GdaSqlExpr *expr)
 	if (!expr) return;
 
 	_gda_sql_expr_check_clean (expr);
-	if (expr->value) {
-		g_value_unset (expr->value);
-		g_free (expr->value);
-	}
+	gda_value_free (expr->value);
 	gda_sql_param_spec_free (expr->param_spec);
 	gda_sql_function_free (expr->func);
 	gda_sql_operation_free (expr->cond);
@@ -96,7 +93,7 @@ gda_sql_expr_free (GdaSqlExpr *expr)
 	}
 	gda_sql_case_free (expr->case_s);
 	g_free (expr->cast_as);
-	expr->value_is_ident = (gpointer) 0x1;
+	expr->value_is_ident = TRUE;
 	g_free (expr);
 }
 
