@@ -209,7 +209,8 @@ void             gda_sql_function_take_args_list (GdaSqlFunction *function, GSLi
  * @GDA_SQL_OPERATOR_TYPE_OR: 
  * @GDA_SQL_OPERATOR_TYPE_EQ: 
  * @GDA_SQL_OPERATOR_TYPE_IS: 
- * @GDA_SQL_OPERATOR_TYPE_LIKE: 
+ * @GDA_SQL_OPERATOR_TYPE_LIKE:
+ * @GDA_SQL_OPERATOR_TYPE_ILIKE:  
  * @GDA_SQL_OPERATOR_TYPE_BETWEEN: 
  * @GDA_SQL_OPERATOR_TYPE_GT: 
  * @GDA_SQL_OPERATOR_TYPE_LT: 
@@ -268,7 +269,8 @@ typedef enum {
 	GDA_SQL_OPERATOR_TYPE_REM,
 	GDA_SQL_OPERATOR_TYPE_BITAND,
 	GDA_SQL_OPERATOR_TYPE_BITOR,
-	GDA_SQL_OPERATOR_TYPE_BITNOT
+	GDA_SQL_OPERATOR_TYPE_BITNOT,
+	GDA_SQL_OPERATOR_TYPE_ILIKE
 } GdaSqlOperatorType;
 
 /**
