@@ -314,7 +314,7 @@ static GType
 _gda_mysql_type_to_gda (G_GNUC_UNUSED MysqlConnectionData *cdata,
 			enum enum_field_types  mysql_type, unsigned int charsetnr)
 {
-	GType gtype = 0;
+	GType gtype;
 	switch (mysql_type) {
 	case MYSQL_TYPE_TINY:
 	case MYSQL_TYPE_SHORT:
@@ -463,7 +463,7 @@ gda_mysql_recordset_new_direct (GdaConnection *cnc, GdaDataModelAccessFlags flag
 		MYSQL_FIELD *field = &mysql_fields[i];
 		
 		GType gtype = model->priv->types [i];
-		if (gtype == 0) {
+		if (gtype == GDA_TYPE_NULL) {
 			gtype = _gda_mysql_type_to_gda (cdata, field->type, field->charsetnr);
 			model->priv->types [i] = gtype;
 		}
@@ -560,8 +560,11 @@ gda_mysql_recordset_new (GdaConnection            *cnc,
 									 gda_column_new ());
 		_GDA_PSTMT (ps)->tmpl_columns = g_slist_reverse (_GDA_PSTMT (ps)->tmpl_columns);
 
-		/* create prepared statement's types */
-		_GDA_PSTMT (ps)->types = g_new0 (GType, _GDA_PSTMT (ps)->ncols); /* all types are initialized to GDA_TYPE_NULL */
+		/* create prepared statement's types, all types are initialized to GDA_TYPE_NULL */
+		_GDA_PSTMT (ps)->types = g_new (GType, _GDA_PSTMT (ps)->ncols);
+		for (i = 0; i < _GDA_PSTMT (ps)->ncols; i++)
+			_GDA_PSTMT (ps)->types [i] = GDA_TYPE_NULL;
+
 		if (col_types) {
 			for (i = 0; ; i++) {
 				if (col_types [i] > 0) {
@@ -607,7 +610,7 @@ gda_mysql_recordset_new (GdaConnection            *cnc,
 		MYSQL_FIELD *field = &mysql_fields[i];
 		
 		GType gtype = _GDA_PSTMT(ps)->types[i];
-		if (gtype == 0) {
+		if (gtype == GDA_TYPE_NULL) {
 			gtype = _gda_mysql_type_to_gda (cdata, field->type, field->charsetnr);
 			_GDA_PSTMT(ps)->types[i] = gtype;
 		}
@@ -826,8 +829,7 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 			}
 			break;
 		case MYSQL_TYPE_NULL:
-			if (G_IS_VALUE(value))
-				g_value_unset (value);
+			gda_value_set_null (value);
 			break;
 		case MYSQL_TYPE_TIME:
 		case MYSQL_TYPE_DATE:
@@ -1002,7 +1004,17 @@ new_row_from_mysql_stmt (GdaMysqlRecordset *imodel, G_GNUC_UNUSED gint rownum, G
 /*
  * Create a new filled #GdaRow object for the row at position @rownum, and put it into *row.
  *
- * Each new GdaRow is given to @model using gda_data_select_take_row().
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row(). If new row objects are "given" to the GdaDataSelect implemantation
+ * using that method, then this method should detect when all the data model rows have been analyzed
+ * (when model->nb_stored_rows == model->advertized_nrows) and then possibly discard the API handle
+ * as it won't be used anymore to fetch rows.
  */
 static gboolean 
 gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
@@ -1014,9 +1026,12 @@ gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
 
 	imodel = GDA_MYSQL_RECORDSET (model);
 
+	if (*row)
+		return TRUE;
+	
 	*row = new_row_from_mysql_stmt (imodel, rownum, error);
 	if (!*row)
-		return TRUE;
+		return FALSE;
 
 	gda_data_select_take_row (model, *row, rownum);
 	
@@ -1032,9 +1047,14 @@ gda_mysql_recordset_fetch_random (GdaDataSelect  *model,
 /*
  * Create a new filled #GdaRow object for the next cursor row, and put it into *row.
  *
- * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
- * Before a new #GdaRow gets created, the previous one, if set, is discarded.
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row().
  */
 static gboolean 
 gda_mysql_recordset_fetch_next (GdaDataSelect  *model,
@@ -1044,33 +1064,43 @@ gda_mysql_recordset_fetch_next (GdaDataSelect  *model,
 {
 	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
 
-	if (imodel->priv->tmp_row)
+	// TO_IMPLEMENT;
+
+	// gda_data_select_iter_next () increments rownum
+
+	if (imodel->priv->tmp_row != NULL) {
 		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
+		imodel->priv->tmp_row = NULL;
+	}
+	
 	*row = new_row_from_mysql_stmt (imodel, rownum, error);
+
 	imodel->priv->tmp_row = *row;
 
-	return TRUE;
+	return *row ? TRUE : FALSE;
 }
 
 /*
- * Create a new filled #GdaRow object for the previous cursor row, and put it into *prow.
+ * Create a new filled #GdaRow object for the previous cursor row, and put it into *row.
  *
- * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
- * Before a new #GdaRow gets created, the previous one, if set, is discarded.
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row().
  */
 static gboolean 
-gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
-				GdaRow        **row,
-				gint            rownum,
-				GError        **error)
+gda_mysql_recordset_fetch_prev (G_GNUC_UNUSED GdaDataSelect  *model,
+				G_GNUC_UNUSED GdaRow        **row,
+				G_GNUC_UNUSED gint            rownum,
+				G_GNUC_UNUSED GError        **error)
 {
-	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
+	/*GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;*/
 
-	if (imodel->priv->tmp_row)
-		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
-	*row = new_row_from_mysql_stmt (imodel, rownum, error);
-	imodel->priv->tmp_row = *row;
+	TO_IMPLEMENT;
 
 	return TRUE;
 }
@@ -1078,22 +1108,24 @@ gda_mysql_recordset_fetch_prev (GdaDataSelect  *model,
 /*
  * Create a new filled #GdaRow object for the cursor row at position @rownum, and put it into *row.
  *
- * Each new #GdaRow created is referenced only by imodel->priv->tmp_row (the #GdaDataSelect implementation
- * never keeps a reference to it).
- * Before a new #GdaRow gets created, the previous one, if set, is discarded.
+ * WARNING: @row will NOT be NULL, but *row may or may not be NULL:
+ *  -  If *row is NULL then a new #GdaRow object has to be created, 
+ *  -  and otherwise *row contains a #GdaRow object which has already been created 
+ *     (through a call to this very function), and in this case it should not be modified
+ *     but the function may return FALSE if an error occurred.
+ *
+ * Memory management for that new GdaRow object is left to the implementation, which
+ * can use gda_data_select_take_row().
  */
 static gboolean 
-gda_mysql_recordset_fetch_at (GdaDataSelect  *model,
-			      GdaRow        **row,
-			      gint            rownum,
-			      GError        **error)
+gda_mysql_recordset_fetch_at (G_GNUC_UNUSED GdaDataSelect  *model,
+			      G_GNUC_UNUSED GdaRow        **row,
+			      G_GNUC_UNUSED gint            rownum,
+			      G_GNUC_UNUSED GError        **error)
 {
-	GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;
-
-	if (imodel->priv->tmp_row)
-		g_object_unref (G_OBJECT(imodel->priv->tmp_row));
-	*row = new_row_from_mysql_stmt (imodel, rownum, error);
-	imodel->priv->tmp_row = *row;
+	/*GdaMysqlRecordset *imodel = (GdaMysqlRecordset*) model;*/
+	
+	TO_IMPLEMENT;
 
 	return TRUE;
 }
