@@ -1,25 +1,33 @@
-/* GDA postgres provider
- * Copyright (C) 1998 - 2010 The GNOME Foundation.
+/*
+ * Copyright (C) 2001 - 2003 Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ * Copyright (C) 2001 - 2004 Rodrigo Moya <rodrigo@gnome-db.org>
+ * Copyright (C) 2002 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ * Copyright (C) 2002 Zbigniew Chyla <cyba@gnome.pl>
+ * Copyright (C) 2003 Akira TAGOH <tagoh@gnome-db.org>
+ * Copyright (C) 2004 - 2005 Alan Knowles <alank@src.gnome.org>
+ * Copyright (C) 2004 Denis Loginov <dloginov@crl.nmsu.edu>
+ * Copyright (C) 2004 Jos Mara Casanova Crespo <jmcasanova@igalia.com>
+ * Copyright (C) 2004 Julio M. Merino Vidal <jmmv@menta.net>
+ * Copyright (C) 2005 - 2009 Bas Driessen <bas.driessen@xobas.com>
+ * Copyright (C) 2005 lvaro Pea <alvaropg@telefonica.net>
+ * Copyright (C) 2006 - 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 Armin Burgmeier <armin@openismus.com>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
  *
- * AUTHORS:
- *         Vivien Malerba <malerba@gnome-db.org>
- *         Rodrigo Moya <rodrigo@gnome-db.org>
- *         Gonzalo Paniagua Javier <gonzalo@gnome-db.org>
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * This Library is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA  02110-1301, USA.
  */
 
 #undef GDA_DISABLE_DEPRECATED
@@ -1365,8 +1373,8 @@ static const gchar*
 gda_postgres_provider_get_default_dbms_type (GdaServerProvider *provider, GdaConnection *cnc, GType type)
 {
 	if (cnc) {
-		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), FALSE);
-		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, FALSE);
+		g_return_val_if_fail (GDA_IS_CONNECTION (cnc), NULL);
+		g_return_val_if_fail (gda_connection_get_provider (cnc) == provider, NULL);
 	}
 
 	if (type == G_TYPE_INT64)
@@ -1413,8 +1421,10 @@ gda_postgres_provider_get_default_dbms_type (GdaServerProvider *provider, GdaCon
                 return "varchar";
         if (type == G_TYPE_UINT)
                 return "int4";
-        if (type == G_TYPE_INVALID)
-                return "text";
+
+	if ((type == GDA_TYPE_NULL) ||
+	    (type == G_TYPE_GTYPE))
+		return NULL;
 
         return "text";
 }
