@@ -1,3 +1,21 @@
+/*
+ * Copyright (C) 2007 - 2008 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2007 - 2011 Vivien Malerba <malerba@gnome-db.org>
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ */
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
@@ -1249,7 +1267,7 @@ typedef struct {
 
 GArray      *expected_signals;
 const gchar *expected_signals_name;
-gint         expected_signals_index;
+guint         expected_signals_index;
 
 /* Format is "<nb><type><row_nb>[/...]"
  * for example: 
