@@ -174,6 +174,8 @@ data_console_init (DataConsole *dconsole, G_GNUC_UNUSED DataConsoleClass *klass)
 	dconsole->priv->layout_type = LAYOUT_HORIZ;
 	dconsole->priv->fav_id = -1;
 	dconsole->priv->popup_container = NULL;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (dconsole), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -236,7 +238,7 @@ data_console_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "DataConsole", &console, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "DataConsole", &console, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_console);
 	}
 	return type;
@@ -292,7 +294,7 @@ data_console_new (BrowserConnection *bcnc)
         GtkWidget *hbox, *label, *wid;
 	gchar *str;
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (dconsole), hbox, FALSE, FALSE, 0);
 
 	str = g_strdup_printf ("<b>%s</b>\n%s", _("Data Manager"), _("Unsaved"));
@@ -316,12 +318,12 @@ data_console_new (BrowserConnection *bcnc)
 
 	/* main container */
 	GtkWidget *hpaned, *nb;
-	hpaned = gtk_hpaned_new ();
+	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (dconsole), hpaned, TRUE, TRUE, 0);
 
 	/* variables */
         GtkWidget *vbox, *sw;
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	dconsole->priv->params_top = vbox;
 	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, FALSE, TRUE);
 
@@ -355,10 +357,10 @@ data_console_new (BrowserConnection *bcnc)
 	dconsole->priv->main_notebook = nb;
 
 	/* editors page */
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_notebook_append_page (GTK_NOTEBOOK (dconsole->priv->main_notebook), vbox, NULL);
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
 	nb = gtk_notebook_new ();
@@ -379,7 +381,7 @@ data_console_new (BrowserConnection *bcnc)
 
 	/* buttons */
 	GtkWidget *bbox, *button;
-	bbox = gtk_vbutton_box_new ();
+	bbox = gtk_button_box_new (GTK_ORIENTATION_VERTICAL);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
 	gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, FALSE, 5);
 
@@ -425,7 +427,7 @@ data_console_new (BrowserConnection *bcnc)
 
 
 	/* data contents page */
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	dconsole->priv->data_box = vbox;
 	gtk_notebook_append_page (GTK_NOTEBOOK (dconsole->priv->main_notebook), vbox, NULL);
 
@@ -580,7 +582,7 @@ save_clicked_cb (GtkWidget *button, DataConsole *dconsole)
 		window = popup_container_new (button);
 		dconsole->priv->popup_container = window;
 
-		hbox = gtk_hbox_new (FALSE, 0);
+		hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 		gtk_container_add (GTK_CONTAINER (window), hbox);
 		wid = gtk_label_new ("");
 		str = g_strdup_printf ("%s:", _("Data manager's name"));
