@@ -1,20 +1,20 @@
 /*
- * Copyright (C) 2010 - 2011 Vivien Malerba
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
- * This Program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -71,7 +71,7 @@ data_source_editor_get_type (void)
 		
 		g_static_mutex_lock (&registering);
 		if (type == 0)
-			type = g_type_register_static (GTK_TYPE_VBOX, "DataSourceEditor", &info, 0);
+			type = g_type_register_static (GTK_TYPE_BOX, "DataSourceEditor", &info, 0);
 		g_static_mutex_unlock (&registering);
 	}
 	return type;
@@ -99,6 +99,9 @@ static void
 data_source_editor_init (DataSourceEditor *editor)
 {
 	GtkWidget *vpaned;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (editor), GTK_ORIENTATION_VERTICAL);
+
 	editor->priv = g_new0 (DataSourceEditorPrivate, 1);
 	editor->priv->attributes = gda_set_new_inline (4,
 						       "id", G_TYPE_STRING, "",
@@ -108,7 +111,7 @@ data_source_editor_init (DataSourceEditor *editor)
 	g_signal_connect (editor->priv->attributes, "holder-changed",
 			  G_CALLBACK (attribute_changed_cb), editor);
 
-	vpaned = gtk_vpaned_new ();
+	vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
 	gtk_box_pack_start (GTK_BOX (editor), vpaned, TRUE, TRUE, 0);
 	gtk_widget_show (vpaned);
 
@@ -147,7 +150,7 @@ data_source_editor_init (DataSourceEditor *editor)
 #define SPACING 3
 	GtkWidget *hbox, *label, *sw, *text;
 	GtkSizeGroup *sg;
-	hbox = gtk_hbox_new (FALSE, SPACING);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING);
 	gtk_paned_add2 (GTK_PANED (vpaned), hbox);
 
 	label = gtk_label_new (_("Dependencies:"));
