@@ -1,20 +1,22 @@
 /*
- * Copyright (C) 2009 - 2011 Vivien Malerba
+ * Copyright (C) 2010 Claude Paroz <claude@2xlibre.net>
+ * Copyright (C) 2010 David King <davidk@openismus.com>
+ * Copyright (C) 2010 Murray Cumming <murrayc@murrayc.com>
+ * Copyright (C) 2010 - 2011 Vivien Malerba <malerba@gnome-db.org>
  *
- * This Library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
  *
- * This Library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #include <string.h>
@@ -986,22 +988,6 @@ data_source_execute (DataSource *source, GError **error)
 	source->priv->executing = FALSE;
 }
 
-/*
- * creates a new string where double underscores '__' are replaced by a single underscore '_'
- */
-static gchar *
-replace_double_underscores (const gchar *str)
-{
-        gchar **arr;
-        gchar *ret;
-
-        arr = g_strsplit (str, "__", 0);
-        ret = g_strjoinv ("_", arr);
-        g_strfreev (arr);
-
-        return ret;
-}
-
 /**
  * data_source_create_grid
  *
@@ -1016,46 +1002,8 @@ data_source_create_grid (DataSource *source)
 		return NULL;
 
 	GtkWidget *fg;
-	GdauiRawGrid *grid;
 	fg = ui_formgrid_new (source->priv->model, FALSE, 0);
-	grid = ui_formgrid_get_grid_widget (UI_FORMGRID (fg));
 
-	GList *columns, *list;
-	columns = gtk_tree_view_get_columns (GTK_TREE_VIEW (grid));
-	for (list = columns; list; list = list->next) {
-		/* reduce column's title */
-		const gchar *title;
-		GtkWidget *header;
-		title = gtk_tree_view_column_get_title (GTK_TREE_VIEW_COLUMN (list->data));
-		header = gtk_label_new ("");
-		if (title) {
-			gchar *tmp, *str;
-			str = replace_double_underscores (title);
-			tmp = g_markup_printf_escaped ("<small>%s</small>", str);
-			g_free (str);
-			gtk_label_set_markup (GTK_LABEL (header), tmp);
-			g_free (tmp);
-		}
-		else
-			gtk_label_set_markup (GTK_LABEL (header), "<small></small>");
-		gtk_widget_show (header);
-		gtk_tree_view_column_set_widget (GTK_TREE_VIEW_COLUMN (list->data),
-						 header);
-		
-		/* reduce text's size */
-		GList *renderers, *list2;
-		renderers = gtk_cell_layout_get_cells (GTK_CELL_LAYOUT (list->data));
-		for (list2 = renderers; list2; list2 = list2->next) {
-			if (GTK_IS_CELL_RENDERER_TEXT (list2->data))
-				g_object_set ((GObject*) list2->data,
-					      "scale", 0.8, NULL);
-		}
-		g_list_free (renderers);
-	}
-	
-	/*if (!columns || !columns->next)*/
-		gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (grid), FALSE);
-	g_list_free (columns);
 	return fg;
 }
 
