@@ -118,6 +118,8 @@ ldap_entries_page_init (LdapEntriesPage *ebrowser, G_GNUC_UNUSED LdapEntriesPage
 	ebrowser->priv->history_items = g_array_new (FALSE, FALSE, sizeof (HistoryItem*));
 	ebrowser->priv->history_max_len = 20;
 	ebrowser->priv->add_hist_item = TRUE;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (ebrowser), GTK_ORIENTATION_VERTICAL);
 }
 
 static void
@@ -172,7 +174,7 @@ ldap_entries_page_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "LdapEntriesPage", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "LdapEntriesPage", &info, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_info);
 	}
 	return type;
@@ -331,13 +333,13 @@ selection_changed_cb (GtkTreeSelection *sel, LdapEntriesPage *ebrowser)
 }
 
 static void
-open_dn_requested_cb (EntryProperties *eprop, const gchar *dn, LdapEntriesPage *ebrowser)
+open_dn_requested_cb (G_GNUC_UNUSED EntryProperties *eprop, const gchar *dn, LdapEntriesPage *ebrowser)
 {
 	ldap_entries_page_set_current_dn (ebrowser, dn);
 }
 
 static void
-open_class_requested_cb (EntryProperties *eprop, const gchar *classname, LdapEntriesPage *ebrowser)
+open_class_requested_cb (G_GNUC_UNUSED EntryProperties *eprop, const gchar *classname, LdapEntriesPage *ebrowser)
 {
 	BrowserPerspective *bpers;
 	bpers = browser_page_get_perspective (BROWSER_PAGE (ebrowser));
@@ -373,14 +375,14 @@ ldap_entries_page_new (BrowserConnection *bcnc, const gchar *dn)
 
 	/* VPaned widget */
 	GtkWidget *hp;
-	hp = gtk_hpaned_new ();
+	hp = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (ebrowser), hp, TRUE, TRUE, 0);
 
 	/* tree */
 	GtkWidget *vbox, *hview, *sw;
 	gfloat yalign;
 
-	vbox = gtk_vbox_new (FALSE, FALSE);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, FALSE);
 	gtk_paned_add1 (GTK_PANED (hp), vbox);
 	
 	str = g_strdup_printf ("<b>%s:</b>", _("LDAP hierarchy"));
@@ -407,7 +409,7 @@ ldap_entries_page_new (BrowserConnection *bcnc, const gchar *dn)
 			  G_CALLBACK (selection_changed_cb), ebrowser);
 
 	/* details */
-	vbox = gtk_vbox_new (FALSE, FALSE);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, FALSE);
 	gtk_paned_add2 (GTK_PANED (hp), vbox);
 
 	str = g_strdup_printf ("<b>%s:</b>", _("LDAP entry's details"));
