@@ -184,7 +184,10 @@ query_console_page_init (QueryConsolePage *tconsole, G_GNUC_UNUSED QueryConsoleP
 	tconsole->priv->params_popup = NULL;
 	tconsole->priv->agroup = NULL;
 	tconsole->priv->fav_id = -1;
+
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (tconsole), GTK_ORIENTATION_VERTICAL);
 }
+
 static void connection_busy_cb (BrowserConnection *bcnc, gboolean is_busy,
 				gchar *reason, QueryConsolePage *tconsole);
 static void
@@ -248,7 +251,7 @@ query_console_page_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GTK_TYPE_VBOX, "QueryConsolePage", &console, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "QueryConsolePage", &console, 0);
 		g_type_add_interface_static (type, BROWSER_PAGE_TYPE, &page_console);
 	}
 	return type;
@@ -293,20 +296,20 @@ query_console_page_new (BrowserConnection *bcnc)
 
 	/* main contents */
 	GtkWidget *vpaned;
-	vpaned = gtk_vpaned_new ();
+	vpaned = gtk_paned_new (GTK_ORIENTATION_VERTICAL);
 	tconsole->priv->vpaned = NULL;
 	gtk_box_pack_start (GTK_BOX (tconsole), vpaned, TRUE, TRUE, 6);	
 
 	/* top paned for the editor */
 	GtkWidget *wid, *vbox, *hbox, *bbox, *hpaned, *button;
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_paned_add1 (GTK_PANED (vpaned), hbox);
 
-	hpaned = gtk_hpaned_new ();
+	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (hbox), hpaned, TRUE, TRUE, 0);
 
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, TRUE, FALSE);
 
 	wid = gtk_label_new ("");
@@ -326,7 +329,7 @@ query_console_page_new (BrowserConnection *bcnc)
 			  G_CALLBACK (editor_execute_request_cb), tconsole);
 	gtk_widget_set_size_request (wid, -1, 200);
 	
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	tconsole->priv->params_top = vbox;
 	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, FALSE, TRUE);
 	
@@ -354,7 +357,7 @@ query_console_page_new (BrowserConnection *bcnc)
 	gtk_container_add (GTK_CONTAINER (tconsole->priv->params_form_box), wid);
 	tconsole->priv->params_form = wid;
 	
-	bbox = gtk_vbutton_box_new ();
+	bbox = gtk_button_box_new (GTK_ORIENTATION_VERTICAL);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
 	gtk_box_pack_start (GTK_BOX (hbox), bbox, FALSE, FALSE, 5);
 
@@ -393,11 +396,11 @@ query_console_page_new (BrowserConnection *bcnc)
 			  G_CALLBACK (sql_favorite_clicked_cb), tconsole);
 
 	/* bottom paned for the results and history */
-	hpaned = gtk_hpaned_new ();
+	hpaned = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_paned_add2 (GTK_PANED (vpaned), hpaned);
 
 	/* bottom left */
-	vbox = gtk_vbox_new (FALSE, 0);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_paned_pack1 (GTK_PANED (hpaned), vbox, FALSE, TRUE);
 
 	wid = gtk_label_new ("");
@@ -415,7 +418,7 @@ query_console_page_new (BrowserConnection *bcnc)
 	g_signal_connect (wid, "changed",
 			  G_CALLBACK (history_changed_cb), tconsole);
 
-	bbox = gtk_hbutton_box_new ();
+	bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 	gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
 	gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
 
@@ -436,7 +439,7 @@ query_console_page_new (BrowserConnection *bcnc)
 	gtk_widget_set_sensitive (button, FALSE);
 
 	/* bottom right */
-	vbox = gtk_vbox_new (FALSE, 8);
+	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 8);
 	gtk_paned_pack2 (GTK_PANED (hpaned), vbox, TRUE, FALSE);
 	
 	wid = gtk_label_new ("");
@@ -758,7 +761,7 @@ sql_favorite_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcon
 }
 
 static void
-sql_favorite_new_mitem_cb (GtkMenuItem *mitem, QueryConsolePage *tconsole)
+sql_favorite_new_mitem_cb (G_GNUC_UNUSED GtkMenuItem *mitem, QueryConsolePage *tconsole)
 {
 	BrowserFavorites *bfav;
 	BrowserFavoritesAttributes fav;
@@ -894,7 +897,7 @@ sql_execute_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcons
 
 				GtkWidget *vbox, *label, *bbox, *button;
 				gchar *str;
-				vbox = gtk_vbox_new (FALSE, 0);
+				vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 				gtk_container_add (GTK_CONTAINER (tconsole->priv->params_popup), vbox);
 				gtk_container_set_border_width (GTK_CONTAINER (tconsole->priv->params_popup), 10);
 
@@ -906,11 +909,11 @@ sql_execute_clicked_cb (G_GNUC_UNUSED GtkButton *button, QueryConsolePage *tcons
 				g_free (str);
 				gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-				cont = gtk_vbox_new (FALSE, 0);
+				cont = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 				gtk_box_pack_start (GTK_BOX (vbox), cont, FALSE, FALSE, 10);
 				g_object_set_data (G_OBJECT (tconsole->priv->params_popup), "cont", cont);
 
-				bbox = gtk_hbutton_box_new ();
+				bbox = gtk_button_box_new (GTK_ORIENTATION_HORIZONTAL);
 				gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, FALSE, 10);
 				gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
 				
