@@ -534,7 +534,7 @@ event (GtkWidget *text_view, GdkEvent *ev, QueryEditor *editor)
 					g_free (editor->priv->current_state_text);
 					editor->priv->current_state_text = query_editor_get_all_text (editor);
 				}
-				else if (editor->priv->current_state >= editor->priv->states->len)
+				else if (editor->priv->current_state >= (gint)editor->priv->states->len)
 					i = editor->priv->states->len - 1; /* last stored state */
 				else if (editor->priv->current_state > 0)
 					i = editor->priv->current_state - 1;
@@ -559,7 +559,7 @@ event (GtkWidget *text_view, GdkEvent *ev, QueryEditor *editor)
 			 (evkey->keyval == GDK_KEY_Down) &&
 			 editor->priv->states) {
 			if (editor->priv->states->len > 0) {
-				if (editor->priv->current_state < editor->priv->states->len - 1) {
+				if (editor->priv->current_state < (gint)editor->priv->states->len - 1) {
 					gchar *tmp;
 					editor->priv->current_state ++;
 					tmp = g_array_index (editor->priv->states, gchar*, editor->priv->current_state);
@@ -661,6 +661,8 @@ query_editor_init (QueryEditor *editor, G_GNUC_UNUSED QueryEditorClass *klass)
 
 	g_return_if_fail (QUERY_IS_EDITOR (editor));
 
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (editor), GTK_ORIENTATION_VERTICAL);
+
 	/* allocate private structure */
 	editor->priv = g_new0 (QueryEditorPrivate, 1);
 	editor->priv->mode = QUERY_EDITOR_READWRITE;
@@ -741,14 +743,13 @@ query_editor_map (GtkWidget *widget)
 {
 	GTK_WIDGET_CLASS (parent_class)->map (widget);
 	if (QUERY_EDITOR (widget)->priv->mode == QUERY_EDITOR_HISTORY) {
-		GtkStyle *style;
-		GdkColor color;
-		style = gtk_widget_get_style (widget);
-		color = style->bg[GTK_STATE_NORMAL];
-		color.red += (65535 - color.red) / COLOR_ALTER_FACTOR;
-		color.green += (65535 - color.green) / COLOR_ALTER_FACTOR;
-		color.blue += (65535 - color.blue) / COLOR_ALTER_FACTOR;
-		gtk_widget_modify_base (QUERY_EDITOR (widget)->priv->text, GTK_STATE_NORMAL, &color);
+		GtkStyleContext* style_context = gtk_widget_get_style_context (widget);
+		GdkRGBA color;
+		gtk_style_context_get_background_color (style_context, GTK_STATE_FLAG_NORMAL, &color);
+		color.red += (1.0 - color.red) / COLOR_ALTER_FACTOR;
+		color.green += (1.0 - color.green) / COLOR_ALTER_FACTOR;
+		color.blue += (1.0 - color.blue) / COLOR_ALTER_FACTOR;
+		gtk_widget_override_background_color (QUERY_EDITOR (widget)->priv->text, GTK_STATE_FLAG_NORMAL, &color);
 	}
 }
 
@@ -842,7 +843,7 @@ query_editor_get_type (void)
 			(GInstanceInitFunc) query_editor_init,
 			0
 		};
-		type = g_type_register_static (GTK_TYPE_VBOX, "QueryEditor", &info, 0);
+		type = g_type_register_static (GTK_TYPE_BOX, "QueryEditor", &info, 0);
 	}
 	return type;
 }
@@ -933,21 +934,20 @@ query_editor_set_mode (QueryEditor *editor, QueryEditorMode mode)
 	}
 
 	if (mode == QUERY_EDITOR_HISTORY) {
-		GtkStyle *style;
-		GdkColor color;
-		style = gtk_widget_get_style ((GtkWidget*) editor);
-		color = style->bg[GTK_STATE_NORMAL];
-		color.red += (65535 - color.red) / COLOR_ALTER_FACTOR;
-		color.green += (65535 - color.green) / COLOR_ALTER_FACTOR;
-		color.blue += (65535 - color.blue) / COLOR_ALTER_FACTOR;
-		gtk_widget_modify_base (editor->priv->text, GTK_STATE_NORMAL, &color);
+		GtkStyleContext *style_context = gtk_widget_get_style_context (GTK_WIDGET (editor));
+		GdkRGBA color;
+		gtk_style_context_get_background_color (style_context, GTK_STATE_FLAG_NORMAL, &color);
+		color.red += (1.0 - color.red) / COLOR_ALTER_FACTOR;
+		color.green += (1.0 - color.green) / COLOR_ALTER_FACTOR;
+		color.blue += (1.0 - color.blue) / COLOR_ALTER_FACTOR;
+		gtk_widget_override_background_color (editor->priv->text, GTK_STATE_FLAG_NORMAL, &color);
 
 		editor->priv->hash = g_hash_table_new_full (NULL, NULL, NULL,
 							    (GDestroyNotify) hist_item_data_unref);
 	}
 	else {
-		gtk_widget_modify_base (editor->priv->text,
-					GTK_STATE_NORMAL, NULL);
+		gtk_widget_override_background_color (editor->priv->text,
+					GTK_STATE_FLAG_NORMAL, NULL);
 	}
 }
 
